==> nifi-2.6.0-source-release.zip: nifi-2.6.0/nifi-frontend/src/main/frontend/apps/nifi/src/app/pages/documentation/ui/processor-definition/processor-definition.component.spec.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import { ComponentFixture, TestBed } from '@angular/core/testing';

import { ProcessorDefinition } from './processor-definition.component';
import { provideMockStore } from '@ngrx/store/testing';
import { processorDefinitionFeatureKey } from '../../state/processor-definition';
import { initialState } from '../../state/processor-definition/processor-definition.reducer';
import { documentationFeatureKey } from '../../state';

describe('ProcessorDefinition', () => {
    let component: ProcessorDefinition;
    let fixture: ComponentFixture<ProcessorDefinition>;

    beforeEach(async () => {
        await TestBed.configureTestingModule({
            imports: [ProcessorDefinition],
            providers: [
                provideMockStore({
                    initialState: {
                        [documentationFeatureKey]: {
                            [processorDefinitionFeatureKey]: initialState
                        }
                    }
                })
            ]
        }).compileComponents();

        fixture = TestBed.createComponent(ProcessorDefinition);
        component = fixture.componentInstance;
        fixture.detectChanges();
    });

    it('should create', () => {
        expect(component).toBeTruthy();
    });
});

==> nifi-2.7.1-source-release.zip: nifi-2.7.1/nifi-frontend/src/main/frontend/apps/nifi/src/app/pages/documentation/ui/processor-definition/processor-definition.component.spec.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import { ComponentFixture, TestBed } from '@angular/core/testing';

import { ProcessorDefinition } from './processor-definition.component';
import { provideMockStore } from '@ngrx/store/testing';
import { processorDefinitionFeatureKey } from '../../state/processor-definition';
import { initialState } from '../../state/processor-definition/processor-definition.reducer';
import { documentationFeatureKey } from '../../state';
import { initialState as initialErrorState } from '../../../../state/error/error.reducer';
import { errorFeatureKey } from '../../../../state/error';
import { initialState as initialCurrentUserState } from '../../../../state/current-user/current-user.reducer';
import { currentUserFeatureKey } from '../../../../state/current-user';

describe('ProcessorDefinition', () => {
    let component: ProcessorDefinition;
    let fixture: ComponentFixture<ProcessorDefinition>;

    beforeEach(async () => {
        await TestBed.configureTestingModule({
            imports: [ProcessorDefinition],
            providers: [
                provideMockStore({
                    initialState: {
                        [errorFeatureKey]: initialErrorState,
                        [currentUserFeatureKey]: initialCurrentUserState,
                        [documentationFeatureKey]: {
                            [processorDefinitionFeatureKey]: initialState
                        }
                    }
                })
            ]
        }).compileComponents();

        fixture = TestBed.createComponent(ProcessorDefinition);
        component = fixture.componentInstance;
        fixture.detectChanges();
    });

    it('should create', () => {
        expect(component).toBeTruthy();
    });
});
